@@ -3,7 +3,7 @@ package App::wordlist;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-22'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.272'; # VERSION
+our $VERSION = '0.273'; # VERSION
 
 use 5.010001;
 use strict;
@@ -313,23 +313,25 @@ sub wordlist {
             return [200, "OK", \%all_stats];
         }
 
-        # optimize: use the wordlist module's pick() if we only use a single
-        # wordlist
-        if ($random && @$wordlists == 1 && $num > 0 && $num <= 100) {
+        # optimize random picking when there's only one wordlist to pick from
+        if ($random && @$wordlists == 1) {
             no strict 'refs';
             my $mod = "WordList::$wordlists->[0]";
             (my $modpm = "$mod.pm") =~ s!::!/!g;
             require $modpm;
-            my $stats = \%{"$mod\::STATS"};
-            my $wl;
-            if ($stats && $stats->{num_words} > 50_000) {
-                require WordListMod;
-                $wl = WordListMod::get_mod_wordlist(
-                    $wordlists->[0], "RandomSeekPick");
-            } else {
-                $wl = $mod->new;
+            my $dynamic = !${"$mod\::DYNAMIC"};
+
+            # not really faster than using each_word()
+            #if (!$dynamic && !$num) {
+            #    my $wl = $mod->new;
+            #    my $fh = \*{"$mod\::DATA"};
+            #    return [200, "OK", [shuffle <$fh>]];
+            #}
+
+            if ($num > 0 && $num <= 100) {
+                my $wl = $mod->new;
+                return [200, "OK", [$wl->pick($num)]];
             }
-            return [200, "OK", [$wl->pick($num)]];
         }
 
         my $n = 0;
@@ -511,7 +513,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.272 of App::wordlist (from Perl distribution App-wordlist), released on 2020-05-22.
+This document describes version 0.273 of App::wordlist (from Perl distribution App-wordlist), released on 2020-05-22.
 
 =head1 SYNOPSIS
 
